@@ -47,7 +47,7 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "22-Nov-22"
+#define SND_DATE "2-Jan-23"
 #ifndef SND_VERSION
 #define SND_VERSION "22.9"
 #endif
